@@ -1,8 +1,9 @@
 package XML::Struct::Writer::Stream;
-our $VERSION = '0.23'; #VERSION
-
+use strict;
 use Moo;
 
+our $VERSION = '0.23';
+
 has fh     => (is => 'rw', default => sub { *STDOUT });
 has pretty => (is => 'rw');
 
@@ -117,34 +118,20 @@ sub end_document {
 
 
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-XML::Struct::Writer::Stream
-
-=head1 VERSION
-
-version 0.23
-
-=head1 DESCRIPTION
-
-This class implements a simplfied SAX handler for stream-based serialization of
-XML. DTDs, comments, processing instructions and similar features not part of
-MicroXML are not supported.
-
-The handler is written to reproduce the serialization of libxml as much as
-possible.
-
 =head1 NAME
 
 XML::Struct::Writer::Stream - simplified SAX handler to serialize (Micro)XML
 
+=head1 DESCRIPTION
+
+This class implements a simplfied SAX handler for stream-based serialization
+of XML. DTDs, comments, processing instructions and similar features not part
+of MicroXML are not supported.
+
+The handler is written to reproduce the serialization of libxml.
+
 =head1 CONFIGURATION
 
 =over
@@ -165,15 +152,4 @@ See L<XML::SAX::Writer>, L<XML::Genx::SAXWriter>, and L<XML::Handler::YAWriter>
 for more elaborated SAX writers and L<XML::Writer> for a general XML writer,
 not based on SAX.
 
-=head1 AUTHOR
-
-Jakob Voß
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
